searchData={"items":[{"type":"task","doc":"Sets up Mneme in your project.\n\nRunning this command will automatically patch the following:\n\n  * `mix.exs` - Adds Mneme's tasks to `:preferred_cli_env`\n  * `.formatter.exs` - Adds `:mneme` to `:import_deps`\n  * `test/test_helper.exs` - Adds `Mneme.start()` after `ExUnit.start()`","title":"mix mneme.install","ref":"Mix.Tasks.Mneme.Install.html"},{"type":"task","doc":"Since your `:mneme` dependency is usually specified with `only: :test`,\nthis task should be run with `MIX_ENV=test`.\n\n```shell\n$ MIX_ENV=test mix mneme.install\n\nIgniter:\nUpdate: .formatter.exs\n\n1 1   |# Used by \"mix format\"\n2 2   |[\n3   - |  inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\"]\n  3 + |  inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\"],\n  4 + |  import_deps: [:mneme]\n4 5   |]\n5 6   |\n\nUpdate: mix.exs\n\n     ...|\n 8  8   |      elixir: \"~> 1.17\",\n 9  9   |      start_permanent: Mix.env() == :prod,\n10    - |      deps: deps()\n   10 + |      deps: deps(),\n   11 + |      preferred_cli_env: [\"mneme.test\": :test, \"mneme.watch\": :test]\n11 12   |    ]\n12 13   |  end\n     ...|\n\nUpdate: test/test_helper.exs\n\n1 1   |ExUnit.start()\n  2 + |Mneme.start()\n\nProceed with changes? [y/n]\n```","title":"Example - mix mneme.install","ref":"Mix.Tasks.Mneme.Install.html#module-example"},{"type":"task","doc":"Run tests with support for Mneme's options at the command line\n\nThis task is like `mix test`, except that it accepts some command line\noptions specific to Mneme. See [\"Command line options\"](#module-command-line-options)\nbelow.","title":"mix mneme.test","ref":"Mix.Tasks.Mneme.Test.html"},{"type":"task","doc":"To ensure `mix mneme.test` runs in the test environment, add a\n`:preferred_cli_env` entry in `mix.exs`:\n\n    def project do\n      [\n        ...\n        preferred_cli_env: [\n          \"mneme.test\": :test,\n          \"mneme.watch\": :test\n        ],\n        ...\n      ]\n    end","title":"Setup - mix mneme.test","ref":"Mix.Tasks.Mneme.Test.html#module-setup"},{"type":"task","doc":"In addition to the options supported by `mix test`, which runs under\nthe hood, the following CLI options are available:\n\n  * `--action [prompt,accept,reject]`\n  * `--default-pattern [infer,first,last]`\n  * `--diff [text,semantic]`\n  * `--diff-style [side_by_side,stacked]`\n  * `--force-update`\n  * `--target [mneme,ex_unit]`\n\nOption documentation is found here: [Mneme – Options](`Mneme#module-options`)","title":"Command line options - mix mneme.test","ref":"Mix.Tasks.Mneme.Test.html#module-command-line-options"},{"type":"task","doc":"Runs the tests for a project when source files change.\n\nThis task is similar to [`mix test.watch`](https://hex.pm/packages/mix_test_watch),\nbut updated to work with Mneme:\n\n  * interrupts Mneme prompts, saving already-accepted changes\n  * doesn't re-trigger when test files are updated by Mneme","title":"mix mneme.watch","ref":"Mix.Tasks.Mneme.Watch.html"},{"type":"task","doc":"To ensure `mix mneme.watch` runs in the test environment, add a\n`:preferred_cli_env` entry in `mix.exs`:\n\n    def project do\n      [\n        ...\n        preferred_cli_env: [\n          \"mneme.test\": :test,\n          \"mneme.watch\": :test\n        ],\n        ...\n      ]\n    end","title":"Setup - mix mneme.watch","ref":"Mix.Tasks.Mneme.Watch.html#module-setup"},{"type":"task","doc":"In addition to the options supported by `mix mneme.test` and `mix test`,\nwhich this task runs under the hood, the following CLI options are\navailable:\n\n  * `--exit-on-success` - stops the test watcher the first time the\n    test suite passes.\n\nAll other CLI arguments are passed to `mix test`, which runs under the\nhood.","title":"Command line options - mix mneme.watch","ref":"Mix.Tasks.Mneme.Watch.html#module-command-line-options"},{"type":"task","doc":"The `--stale` command line option is especially useful. Run by itself,\n`mix mneme.watch` will run all of your tests when any source file or\ntest is saved. When used with `--stale`, only tests that have gone\nstale due to changes in `lib` will be re-run, greatly speeding up most\ntest runs.\n\nFor more information, see the `mix test` documentation for\n[the `--stale` option](https://hexdocs.pm/mix/Mix.Tasks.Test.html#module-the-stale-option).","title":"The --stale option - mix mneme.watch","ref":"Mix.Tasks.Mneme.Watch.html#module-the-stale-option"},{"type":"task","doc":"```sh\n$ mix mneme.watch --only some_tag\n# runs tests tagged with `some_tag: true`\n\n$ mix mneme.watch test/my_app/my_test.exs\n# runs tests in the given file\n\n$ mix mneme.watch --stale\n# runs stale tests\n```","title":"Examples - mix mneme.watch","ref":"Mix.Tasks.Mneme.Watch.html#module-examples"},{"type":"module","doc":"Augments `ExUnit.Assertions` with a set of assertions that know how to\nupdate themselves.\n\nTo learn more about how Mneme's auto-assertions are updated, see the\n[pattern generation guide](docs/guides/generated_patterns.md).\n\n> #### `use Mneme` {: .info}\n>\n> When you `use Mneme` in a test module, [assertions](#assertions) are\n> imported and module attributes are made available for\n> [configuration](#configuration).","title":"Mneme","ref":"Mneme.html"},{"type":"module","doc":"Mneme supports a variety of flexible configuration options that can be\napplied at multiple levels of granularity, from your entire test suite\ndown to an individual test. While the default behavior will work well\nfor the majority of cases, it's worth knowing which levers and knobs\nyou have available to tweak Mneme to fit your individual workflow.","title":"Configuration - Mneme","ref":"Mneme.html#module-configuration"},{"type":"module","doc":"* `:action` (`:prompt | :accept | :reject`) - The action to be taken when an auto-assertion updates. If `CI=true`\n  is set in environment variables, the action will _always_ be\n  `:reject`. The default value is `:prompt`.\n\n* `:default_pattern` (`:infer | :first | :last`) - The default pattern to be selected if prompted to update an assertion. The default value is `:infer`.\n\n* `:diff` (`:text | :semantic`) - Controls the diff engine used to display changes when an auto-\n  assertion updates. If `:semantic`, uses a custom diff engine to\n  highlight only meaningful changes in the value. If `:text`, uses\n  the Myers Difference algorithm to highlight all changes in text. The default value is `:semantic`.\n\n* `:diff_style` (`:side_by_side | :stacked`) - Controls how diffs are rendered when the `:diff` option is set to\n  `:semantic`. If `:side_by_side`, old and new code will be rendered\n  side-by-side if the terminal has sufficient space. If `:stacked`,\n  old and new code will be rendered one on top of the other. The default value is `:side_by_side`.\n\n* `:force_update` (`t:boolean/0`) - Setting to `true` will force auto-assertions to update even when\n  they would otherwise succeed. This can be especially helpful when\n  adding new keys to maps or structs since a pattern like `%{}`\n  would not normally prompt as the match still succeeds. The default value is `false`.\n\n* `:target` (`:mneme | :ex_unit`) - The target output for auto-assertions. If `:mneme`, the expression\n  will remain an auto-assertion. If `:ex_unit`, the expression will\n  be rewritten as an ExUnit assertion. The default value is `:mneme`.","title":"Options - Mneme","ref":"Mneme.html#module-options"},{"type":"module","doc":"There are four ways you can apply configuration options; Each is more\nspecific than the last and will override any conflicting options that\nwere set prior.\n\n  * When calling `Mneme.start/1`, which will apply to the entire test\n    run;\n  * When calling `use Mneme`, which will apply to all tests in that\n    module;\n  * In a `@mneme_describe` module attribute, which will apply to all\n    tests that follow in the given `ExUnit.Case.describe/2` block;\n  * In a `@mneme` module attribute, which will apply only to the next\n    test that follows.\n\nFor instance, when an auto-assertion has multiple possible patterns\navailable, Mneme will try to infer the best one to show you first.\nIf you always want the last (and usually most complex) generated\npattern, you could call `Mneme.start/1` like this:\n\n    # test/test_helper.exs\n    ExUnit.start()\n    Mneme.start(default_pattern: :last)\n\nAs mentioned above, this can be overriden at the module-level, in a\n`describe` block, or for an individual test:\n\n    defmodule MyTest do\n      use ExUnit.Case\n      use Mneme, default_pattern: :infer\n\n      test \"the default pattern will exclude :baz when this runs\" do\n        map = %{foo: :one, baz: :three}\n        auto_assert %{foo: 1, bar: 2} <- Map.put(map, bar: :two)\n      end\n\n      describe \"...\" do\n        @mneme_describe action: :reject\n\n        test \"fails without prompting\" do\n          auto_assert :wrong <- MyModule.some_fun()\n        end\n\n        @mneme action: :prompt\n        test \"prompts to update\" do\n          auto_assert :wrong <- MyModule.another_fun()\n        end\n      end\n    end\n\nBreaking up with Mneme? While the official stance of the library is\nthat this is Not Recommended™, Mneme can even convert all of your\nexisting auto-assertions to regular assertions:\n\n    Mneme.start(\n      target: :ex_unit,\n      force_update: true,\n      action: :accept\n    )\n\nProbably don't do this, but if you do, make sure all your tests are\ncommitted first in case you want to get back together.","title":"Configuring Mneme - Mneme","ref":"Mneme.html#module-configuring-mneme"},{"type":"macro","doc":"Pattern-match operator.\n\nThis operator can only be used in `auto_assert/1` or other special\nforms that support it, like `for/1`.\n\nWhile it is similar to the match operator `=/2`, there are a few\ndifferences:\n\n  * It can be used to match falsy values. For instance, the following\n    `ExUnit` assertion using `=/2` will always fail, whereas the\n    auto-assertion using `<-` will not:\n\n        # fails\n        assert false = false\n\n        # succeeds\n        auto_assert false <- false\n\n  * It supports guards on the pattern with a `when` clause\n\n        auto_assert pid when is_pid(pid) <- self()","title":"Mneme.<-/2","ref":"Mneme.html#%3C-/2"},{"type":"macro","doc":"Pattern-generating variant of `ExUnit.Assertions.assert/1`.\n\nSee also:\n\n  * `<-/2` - pattern-matching operator used with this macro\n  * The [pattern generation guide](docs/guides/generated_patterns.md)\n\nSee the","title":"Mneme.auto_assert/1","ref":"Mneme.html#auto_assert/1"},{"type":"macro","doc":"`auto_assert` generates assertions when tests run, issuing a terminal\nprompt before making any changes (unless configured otherwise).\n\n    auto_assert [1, 2] ++ [3, 4]\n\n    # after running the test and accepting the change\n    auto_assert [1, 2, 3, 4] <- [1, 2] ++ [3, 4]\n\nIf the match no longer succeeds, you'll be prompted to update it to\nthe new value.\n\n    auto_assert [1, 2, 3, 4] <- [1, 2] ++ [:a, :b]\n\n    # after running the test and accepting the change\n    auto_assert [1, 2, :a, :b] <- [1, 2] ++ [:a, :b]\n\nYou're only prompted if the pattern doesn't match. This means you can\nmanually change patterns to ignore parts of the structure you don't\ncare about, and the assertion will still succeed.\n\n    # this assertion succeeds, so no prompt is issued\n    auto_assert [1, 2, | _] <- [1, 2] ++ [:a, :b]","title":"Usage - Mneme.auto_assert/1","ref":"Mneme.html#auto_assert/1-usage"},{"type":"macro","doc":"See `auto_assert_raise/3`.","title":"Mneme.auto_assert_raise/1","ref":"Mneme.html#auto_assert_raise/1"},{"type":"macro","doc":"See `auto_assert_raise/3`.","title":"Mneme.auto_assert_raise/2","ref":"Mneme.html#auto_assert_raise/2"},{"type":"macro","doc":"Pattern-generating variant of `ExUnit.Assertions.assert_raise/3`.\n\nIf the given function does not raise, the assertion will fail.\n\nLike `auto_assert/1`, you will be prompted to automatically update\nthe assertion if the raised raised exception changes.","title":"Mneme.auto_assert_raise/3","ref":"Mneme.html#auto_assert_raise/3"},{"type":"macro","doc":"You can pass an anonymous function that takes no arguments and is\nexpected to raise an exception.\n\n    auto_assert_raise fn ->\n      some_call_expected_to_raise()\n    end\n\n    # after running the test and accepting changes\n    auto_assert_raise Some.Exception, fn ->\n      some_call_expected_to_raise()\n    end\n\n    # optionally include the message\n    auto_assert_raise Some.Exception, \"perhaps with a message\", fn ->\n      some_call_expected_to_raise()\n    end\n\nA captured function of arity zero can also be used.\n\n    auto_assert_raise &some_call_expected_to_raise/0\n\n    # after running the test and accepting changes\n    auto_assert_raise Some.Exception, &some_call_expected_to_raise/0","title":"Examples - Mneme.auto_assert_raise/3","ref":"Mneme.html#auto_assert_raise/3-examples"},{"type":"macro","doc":"See `auto_assert_receive/2`.","title":"Mneme.auto_assert_receive/0","ref":"Mneme.html#auto_assert_receive/0"},{"type":"macro","doc":"See `auto_assert_receive/2`.","title":"Mneme.auto_assert_receive/1","ref":"Mneme.html#auto_assert_receive/1"},{"type":"macro","doc":"Pattern-generating variant of `ExUnit.Assertions.assert_receive/3`.\n\n`timeout` is in milliseconds and defaults to `100`.","title":"Mneme.auto_assert_receive/2","ref":"Mneme.html#auto_assert_receive/2"},{"type":"macro","doc":"Process.send_after(self(), {:some, :message}, 50)\n\n    auto_assert_receive()\n\n    # after running the test, messages appearing within 100ms\n    # will be available as options\n    auto_assert_receive {:some, :message}\n\nA custom timeout can be specified as a second argument.\n\n    Process.send_after(self(), {:some, :message}, 150)\n\n    auto_assert_receive nil, 300\n\n    # messages appearing within 300ms will now appear as options\n    auto_assert_receive {:some, :message}, 300","title":"Examples - Mneme.auto_assert_receive/2","ref":"Mneme.html#auto_assert_receive/2-examples"},{"type":"macro","doc":"See `auto_assert_received/1`.","title":"Mneme.auto_assert_received/0","ref":"Mneme.html#auto_assert_received/0"},{"type":"macro","doc":"Pattern-generating variant of `ExUnit.Assertions.assert_received/2`.\n\nSimilar to `auto_assert_receive/2`, except that the timeout is set to\n0, so the expected message must already be in the current process'\nmailbox.","title":"Mneme.auto_assert_received/1","ref":"Mneme.html#auto_assert_received/1"},{"type":"macro","doc":"send(self(), {:some, :message})\n\n    auto_assert_received()\n\n    # after running the test, messages in the current process\n    # inbox will be available as options\n    auto_assert_receive {:some, :message}","title":"Examples - Mneme.auto_assert_received/1","ref":"Mneme.html#auto_assert_received/1-examples"},{"type":"function","doc":"Start Mneme, allowing auto-assertions to run as they appear in tests.\n\nThis will almost always be added to your `test/test_helper.exs`, just\nbelow the call to `ExUnit.start()`:\n\n    # test/test_helper.exs\n    ExUnit.start()\n    Mneme.start()","title":"Mneme.start/1","ref":"Mneme.html#start/1"},{"type":"function","doc":"* `:action` (`:prompt | :accept | :reject`) - The action to be taken when an auto-assertion updates. If `CI=true`\n  is set in environment variables, the action will _always_ be\n  `:reject`. The default value is `:prompt`.\n\n* `:default_pattern` (`:infer | :first | :last`) - The default pattern to be selected if prompted to update an assertion. The default value is `:infer`.\n\n* `:diff` (`:text | :semantic`) - Controls the diff engine used to display changes when an auto-\n  assertion updates. If `:semantic`, uses a custom diff engine to\n  highlight only meaningful changes in the value. If `:text`, uses\n  the Myers Difference algorithm to highlight all changes in text. The default value is `:semantic`.\n\n* `:diff_style` (`:side_by_side | :stacked`) - Controls how diffs are rendered when the `:diff` option is set to\n  `:semantic`. If `:side_by_side`, old and new code will be rendered\n  side-by-side if the terminal has sufficient space. If `:stacked`,\n  old and new code will be rendered one on top of the other. The default value is `:side_by_side`.\n\n* `:force_update` (`t:boolean/0`) - Setting to `true` will force auto-assertions to update even when\n  they would otherwise succeed. This can be especially helpful when\n  adding new keys to maps or structs since a pattern like `%{}`\n  would not normally prompt as the match still succeeds. The default value is `false`.\n\n* `:target` (`:mneme | :ex_unit`) - The target output for auto-assertions. If `:mneme`, the expression\n  will remain an auto-assertion. If `:ex_unit`, the expression will\n  be rewritten as an ExUnit assertion. The default value is `:mneme`.\n\n\n\nFor more information about configuring Mneme, see the\n[Configuration](#module-configuration) section of the module docs.","title":"Options - Mneme.start/1","ref":"Mneme.html#start/1-options"},{"type":"extras","doc":"# Changelog\n\nThis format is based on [Keep a Changelog](https://keepachangelog.com) and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"","title":"v0.10.2 (2025-01-24) - Changelog","ref":"changelog.html#v0-10-2-2025-01-24"},{"type":"extras","doc":"* [@JonasGruenwald](https://github.com/JonasGruenwald) - Support [Igniter](https://hexdocs.pm/igniter/readme.html) versions 0.5.0+ ([#106](https://github.com/zachallaun/mneme/issues/106)).","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"","title":"v0.10.1 (2024-12-17) - Changelog","ref":"changelog.html#v0-10-1-2024-12-17"},{"type":"extras","doc":"* Fixed a crash that occurred when generating patterns for improper lists ([#105](https://github.com/zachallaun/mneme/issues/105)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.10.0 (2024-11-07) - Changelog","ref":"changelog.html#v0-10-0-2024-11-07"},{"type":"extras","doc":"* `mix mneme.test`, which is functionally equivalent to `mix test` except that it allows Mneme's configuration options to be passed at the command line.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* `mix mneme.watch` now uses `mix mneme.test` under the hood so that it can accept the same options.\n    * This means that `mneme.test` needs to be added to your `:preferred_cli_env` in `mix.exs`: `preferred_cli_env: [\"mneme.test\": :test, \"mneme.watch\": :test]`.\n    * Running `MIX_ENV=test mix mneme.install` will update this for you.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Ensure that the module is loaded before generating struct patterns ([#102](https://github.com/zachallaun/mneme/issues/102)).\n  * If an existing string pattern is using `\"\"\"`, use the same by default if the string changes ([#80](https://github.com/zachallaun/mneme/issues/80)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.9.4 (2024-10-28) - Changelog","ref":"changelog.html#v0-9-4-2024-10-28"},{"type":"extras","doc":"* `mix mneme.install`, an [Igniter](https://github.com/ash-project/igniter) task that simplifies setup.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"","title":"v0.9.3 (2024-10-21) - Changelog","ref":"changelog.html#v0-9-3-2024-10-21"},{"type":"extras","doc":"* Don't simplify structs used as keys in maps ([#96](https://github.com/zachallaun/mneme/issues/96)).\n  * [mix mneme.watch] Ensure the `:ex_unit` application is started before accessing its application config ([#95](https://github.com/zachallaun/mneme/issues/95)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.9.2 (2024-10-14) - Changelog","ref":"changelog.html#v0-9-2-2024-10-14"},{"type":"extras","doc":"* Added `--exit-on-success` flag to `mix mneme.watch`, which reruns tests until all of them pass, then exits.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* Prevent an increasing number of \"Running ExUnit with seed...\" messages from printing during runs of `mix mneme.watch`. This was a regression introduced in v0.9.1.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.9.1 (2024-10-14) - Changelog","ref":"changelog.html#v0-9-1-2024-10-14"},{"type":"extras","doc":"* Don't override existing ExUnit formatters ([#87](https://github.com/zachallaun/mneme/issues/87)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.9.0 (2024-10-08) - Changelog","ref":"changelog.html#v0-9-0-2024-10-08"},{"type":"extras","doc":"* `mix mneme.watch`, a test runner that watches source files for changes and automatically re-runs your tests. It's Mneme-aware, which means it can interrupt prompts and save already-accepted tests if a file system change is detected mid-run.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* Fix crash that could occur when generating heredoc strings with repeated newlines ([#85](https://github.com/zachallaun/mneme/issues/85)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.8.2 (2024-07-11) - Changelog","ref":"changelog.html#v0-8-2-2024-07-11"},{"type":"extras","doc":"* Added `J` and `K` to jump to the first and last pattern when multiple patterns are offered in a prompt. (`J` and `K` were previously equivalent to `j` and `k`, respectively.)","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* Don't suggest duplicate patterns when updating lists (or other containers of) maps.\n  * Don't generate incorrect map patterns when updating an existing pattern that is a partial match of a new value. For instance, when updating the pattern `%{x: 1, y: 2, z: 3}` for the new value `%{x: 1, y: 2}`, the incorrect pattern `%{x: 1, y: 2, z: nil}` would be suggested.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.8.1 (2024-06-20) - Changelog","ref":"changelog.html#v0-8-1-2024-06-20"},{"type":"extras","doc":"* Fix a diff bug that could cause some deleted or added code to go unhighlighted.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.8.0 (2024-06-20) - Changelog","ref":"changelog.html#v0-8-0-2024-06-20"},{"type":"extras","doc":"* [@am-kantox](https://github.com/am-kantox) - Variables bound in `auto_assert` patterns remain in scope ([#1](https://github.com/zachallaun/mneme/issues/1)).\n  * Print a warning when an auto-assertion that will always succeed is encountered.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"This is the first version supporting Elixir 1.17.0 and Erlang/OTP 27.","title":"v0.7.0 (2024-05-27) - Changelog","ref":"changelog.html#v0-7-0-2024-05-27"},{"type":"extras","doc":"* Update docs to reflect `-0.0` being a possible generated value when using Erlang/OTP 27 or later.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Fix diff highlighting of the map opening delimiter `%{` when using Elixir 1.17+.\n  * Fix warnings during testing when using Elixir 1.17+.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.6.1 (2024-05-21) - Changelog","ref":"changelog.html#v0-6-1-2024-05-21"},{"type":"extras","doc":"* Update map and struct patterns that ignore keys more intelligently, e.g. `%{x: 1, y: _}` will now still use `_` for `:y` when `:x` changes.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* Fix a crash that would occur when generating a pattern for a non-existing struct, e.g. `%{__struct__: Foo}` when `Foo` is not a module defining a struct ([#67](https://github.com/zachallaun/mneme/issues/67)).\n  * Generate the signed pattern `+0.0` for the float `0.0` to avoid the warning about `+0.0` and `-0.0` no longer matching in Erlang/OTP 27. (Mneme will gain support for generating `-0.0` patterns in the future.)","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.6.0 (2024-04-15) - Changelog","ref":"changelog.html#v0-6-0-2024-04-15"},{"type":"extras","doc":"* Calling `Mneme.start/1` multiple times now has the same behavior as `Mneme.start(restart: true)`. The `:restart` option is now a no-op and specifying it will print a notice.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Tests using Mneme can now be compiled individually without having first called `Mneme.start/1`. Previously, an error would be raised at compile-time, interfering with some language servers ([lexical-lsp/lexical#507](https://github.com/lexical-lsp/lexical/issues/507)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.5.1 (2024-04-13) - Changelog","ref":"changelog.html#v0-5-1-2024-04-13"},{"type":"extras","doc":"* Updated some dependencies for better compatibility with other libraries.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"While this release does not include breaking changes, the minor version is being bumped because the change to map patterns described below may be unexpected.","title":"v0.5.0 (2024-02-06) - Changelog","ref":"changelog.html#v0-5-0-2024-02-06"},{"type":"extras","doc":"* Empty maps will no longer be suggested as patterns for non-empty maps. For instance, `auto_assert %{foo: 1}` will no longer suggest `auto_assert %{} <- %{foo: 1}`. Note that empty structs will still be suggested ([#55](https://github.com/zachallaun/mneme/issues/55), [#56](https://github.com/zachallaun/mneme/issues/56), [#57](https://github.com/zachallaun/mneme/issues/57)).","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Generate struct patterns for `DateTime` when the sigil cannot be used ([#59](https://github.com/zachallaun/mneme/issues/59)).\n  * Correctly escape non-printable characters in string literals, like `\\r` ([#62](https://github.com/zachallaun/mneme/issues/62)).\n  * Fix a crash that could occur due to incorrect handling of the source file being changed while Mneme was running.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.4.3 (2023-11-02) - Changelog","ref":"changelog.html#v0-4-3-2023-11-02"},{"type":"extras","doc":"* Fix a regression introduced in v0.4.1 that caused auto-assertions to fail if an earlier one in the same file added or removed lines when formatted ([#53](https://github.com/zachallaun/mneme/issues/53)).\n  * Suppress \"unused alias\" warnings when the aliases are only used in auto-assertions ([#54](https://github.com/zachallaun/mneme/issues/54)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.4.2 (2023-11-01) - Changelog","ref":"changelog.html#v0-4-2-2023-11-01"},{"type":"extras","doc":"* Fix a crash that would occur if a test file containing an auto-assertion is changed before the auto-assertion is run (for instance, while Mneme is waiting on input from an auto-assertion in a different test file).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.4.1 (2023-10-25) - Changelog","ref":"changelog.html#v0-4-1-2023-10-25"},{"type":"extras","doc":"* Fix a crash that could occur when diffing sigils ([#52](https://github.com/zachallaun/mneme/issues/52)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.4.0 (2023-07-04) - Changelog","ref":"changelog.html#v0-4-0-2023-07-04"},{"type":"extras","doc":"* `Mneme.start/1` now accepts all of Mneme's configuration options that will be applied to the entire test run.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* **Breaking:** Removed support for `:mneme` application config. This has been replaced by passing config options directly to `Mneme.start/1`:\n\n      ```elixir\n      # Old: config/test.exs\n      config :mneme, defaults: [default_pattern: :last, ...]\n\n      # New: test/test_helper.exs\n      Mneme.start(default_pattern: :last, ...)\n      ```","title":"Removed - Changelog","ref":"changelog.html#removed"},{"type":"extras","doc":"","title":"v0.3.5 (2023-06-30) - Changelog","ref":"changelog.html#v0-3-5-2023-06-30"},{"type":"extras","doc":"* Support multi-letter sigils when using Elixir 1.15.0+.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.3.4 (2023-05-22) - Changelog","ref":"changelog.html#v0-3-4-2023-05-22"},{"type":"extras","doc":"* Tested to support OTP 26.0 when using Elixir 1.14.4.\n  * Support expressions that return functions, serializing them with an `is_function(fun, arity)` guard.\n  * When generating a pattern for a MapSet, add a note suggesting using `MapSet.to_list/1` for better serialization.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* Format pattern notes to be more obvious when they're present.\n  * Generate charlist patterns using `sigil_c` instead of single quotes, e.g. `~c\"foo\"` instead of `'foo'`. See [this discussion](https://elixirforum.com/t/convert-charlists-into-c-charlists/49455) for more context.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Numerous fixes related to vars used in guards:\n    * Generated vars will no longer shadow variables in scope (e.g. if `pid` is in scope, a different pid will use the var `pid1`).\n    * The same var will no longer be used for different values of the same type.\n    * Multiple, redundant guards will no longer be emitted for the same var (e.g. `[self(), self()]` would result in `[pid, pid] when is_pid(pid) and is_pid(pid)`).\n  * Numerous fixes related to pattern generation, especially in regards to map keys.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.3.3 (2023-05-01) - Changelog","ref":"changelog.html#v0-3-3-2023-05-01"},{"type":"extras","doc":"* Improve stacktraces and ExUnit assertion errors when an auto-assertion fails or is rejected.\n  * When an `auto_assert` updates, a default pattern that is more similar to the existing one will be selected in more cases when the `:default_pattern` option is set to `:infer` (the default).\n  * When updating an assertion with an existing map pattern that only asserts a subset of keys, generate a pattern using that subset as well.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"","title":"v0.3.2 (2023-04-16) - Changelog","ref":"changelog.html#v0-3-2-2023-04-16"},{"type":"extras","doc":"* Multi-line string patterns will now always appear in the same order (heredoc format will always be the last option).","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Raise a more comprehensible error if `Mneme.start()` is called multiple times without `restart: true`.\n  * Fix an incorrect guard that could cause semantic diffing to fail and fall back to text diffing.\n  * Fix multi-line string formatting issues with `auto_assert_raise`, `auto_assert_receive`, and `auto_assert_received`.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.3.1 (2023-04-14) - Changelog","ref":"changelog.html#v0-3-1-2023-04-14"},{"type":"extras","doc":"* Multi-line strings will now generate both a heredoc and a single-line option.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* No longer depend on `libgraph`.","title":"Removed - Changelog","ref":"changelog.html#removed"},{"type":"extras","doc":"It is recommended to now use Elixir v1.14.4 or later.","title":"v0.3.0 (2023-04-10) - Changelog","ref":"changelog.html#v0-3-0-2023-04-10"},{"type":"extras","doc":"* Add three new auto-assertions:\n    * [`auto_assert_raise`](https://hexdocs.pm/mneme/Mneme.html#auto_assert_raise/3)\n    * [`auto_assert_receive`](https://hexdocs.pm/mneme/Mneme.html#auto_assert_receive/2)\n    * [`auto_assert_received`](https://hexdocs.pm/mneme/Mneme.html#auto_assert_received/1)\n  * Add a `:force_update` option that forces re-generating assertion patterns even when they succeed. See the [Options documentation](https://hexdocs.pm/mneme/Mneme.html#module-options) for more info.\n  * Prompts will now show options that were overridden from the defaults.\n  * Mneme now prints a one-line summary at the end of the test run.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* For falsy values, `auto_assert` now generates `<-` pattern matches instead of `==` value comparisons, which have been removed.\n  * Existing auto-assertions will now run when `Mneme.start()` is not called, but new or failing auto-assertions will fail without prompting ([#32](https://github.com/zachallaun/mneme/issues/32)).\n  * Ranges now use range syntax like `1..10` and `1..10//2` instead of generating a `%Range{}` struct.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* **Breaking:** `auto_assert` no longer supports value comparisons using `==`.","title":"Removed - Changelog","ref":"changelog.html#removed"},{"type":"extras","doc":"* Fix a configuration precedence bug that caused options set in application config to always override module, describe, or test options.\n  * Fix a compatibility issue with Ecto ~> 3.9.4 ([#34](https://github.com/zachallaun/mneme/issues/34)).\n  * Fix a confusing diff result that could occur with some binary operations ([#11](https://github.com/zachallaun/mneme/issues/11)).\n  * Preceding comments are no longer shown in diffs ([#26](https://github.com/zachallaun/mneme/issues/26)).\n  * Fix a number of diffing errors related to structs.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.2.7 (2023-03-29) - Changelog","ref":"changelog.html#v0-2-7-2023-03-29"},{"type":"extras","doc":"* Fix a crash related to escaped string interpolation characters ([#29](https://github.com/zachallaun/mneme/issues/29)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.2.6 (2023-03-27) - Changelog","ref":"changelog.html#v0-2-6-2023-03-27"},{"type":"extras","doc":"* Auto-assertion prompts can now be skipped (`s`) in addition to accepted (`y`) or rejected (`n`). This allows the test clause to continue so that later assertions might be run, but fails the test run once the suite finishes.\n  * Semantic diffs will now be displayed side-by-side if terminal width allows. To always display diffs stacked, use the `diff_style: :stacked` option; see the \"Configuration\" section of the `Mneme` module doc for more.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* Semantic diff formatting has been improved for clarity.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Don't overwrite test files if their content changes after starting the test run ([#23](https://github.com/zachallaun/mneme/issues/23)).\n  * Fix a crash that occurred when a value contained nested strings with newlines, e.g. `{:ok, \"hello\\nworld\"}` ([#25](https://github.com/zachallaun/mneme/issues/25)).\n  * The `j/k` options will no longer be rendered when prompting if there is only a single pattern option.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.2.4, v0.2.5 (2023-03-25) - Changelog","ref":"changelog.html#v0-2-4-v0-2-5-2023-03-25"},{"type":"extras","doc":"* Remove unnecessary files from Hex package. This cuts the package size down drastically.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.2.3 (2023-03-25) - Changelog","ref":"changelog.html#v0-2-3-2023-03-25"},{"type":"extras","doc":"* Fix diffing for certain sigil variations.\n  * Fix `dbg`-related error when running `MIX_ENV=test iex -S mix` ([#20](https://github.com/zachallaun/mneme/issues/20)).\n  * Fix ETS-related error when calling `Mneme.start/1` multiple times ([#20](https://github.com/zachallaun/mneme/issues/20#issuecomment-1483878101)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.2.2 (2023-03-20) - Changelog","ref":"changelog.html#v0-2-2-2023-03-20"},{"type":"extras","doc":"* Disable a semantic diffing optimization that caused poor diff results in certain cases, usually manifesting as incorrect branches being compared.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.2.1 (2023-03-19) - Changelog","ref":"changelog.html#v0-2-1-2023-03-19"},{"type":"extras","doc":"* More consistent formatting between `:semantic` and `:text` diffs.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"","title":"v0.2.0 (2023-03-18) - Changelog","ref":"changelog.html#v0-2-0-2023-03-18"},{"type":"extras","doc":"* Adds semantic diffs which selectively highlight only meaningful changes when updating an assertion. This can be disabled with the `diff: :text` option; see the \"Configuration\" section of the `Mneme` module doc for more.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* **Breaking:** Mneme now requires Elixir v1.14 or later.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"* Invalid options now cause a warning instead of crashing test process.\n  * Internal errors now show an error instead of crashing test process.\n  * Fix bug causing multiple identical choices to be presented in some cases where empty lists were a part of the value.","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.1.6 (2023-03-04) - Changelog","ref":"changelog.html#v0-1-6-2023-03-04"},{"type":"extras","doc":"* Improved compile-time error message when `auto_assert` is used outside of a `test` block ([#9](https://github.com/zachallaun/mneme/issues/9)).","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"","title":"v0.1.5 (2023-02-25) - Changelog","ref":"changelog.html#v0-1-5-2023-02-25"},{"type":"extras","doc":"* More consistent handling of charlists: lists of integers will now generate themselves as a pattern as well as a charlist if the list is ASCII printable ([#6](https://github.com/zachallaun/mneme/issues/6)).","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"","title":"v0.1.4 (2023-02-23) - Changelog","ref":"changelog.html#v0-1-4-2023-02-23"},{"type":"extras","doc":"* Fix a bug that could cause `auto_assert` expressions to revert to the previous value when using `Mneme.start(restart: true)` ([#7](https://github.com/zachallaun/mneme/issues/7)).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.1.3 (2023-02-22) - Changelog","ref":"changelog.html#v0-1-3-2023-02-22"},{"type":"extras","doc":"* Add a `:default_pattern` configuration option for auto-assertions which controls the pattern that should be selected by default when prompted.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"* When converting an auto-assertion to an ExUnit assertion, select the identical pattern when the `:default_pattern` is `:infer` (set by default).","title":"Fixed - Changelog","ref":"changelog.html#fixed"},{"type":"extras","doc":"","title":"v0.1.2 (2023-02-21) - Changelog","ref":"changelog.html#v0-1-2-2023-02-21"},{"type":"extras","doc":"* Add a `:restart` option to `Mneme.start/1` to restart Mneme if called multiple times.","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"","title":"v0.1.1 (2023-02-20) - Changelog","ref":"changelog.html#v0-1-1-2023-02-20"},{"type":"extras","doc":"* Dramatically reduce the performance gap between `auto_assert` and ExUnit's `assert`.","title":"Changed - Changelog","ref":"changelog.html#changed"},{"type":"extras","doc":"First release.","title":"v0.1.0 (2023-02-19) - Changelog","ref":"changelog.html#v0-1-0-2023-02-19"},{"type":"extras","doc":"# /ˈniːmiː/ - Snapshot testing utilities for Elixir\n\n[![Hex.pm](https://img.shields.io/hexpm/v/mneme.svg)](https://hex.pm/packages/mneme)\n[![Docs](https://img.shields.io/badge/hexdocs-docs-8e7ce6.svg)](https://hexdocs.pm/mneme)\n[![CI](https://github.com/zachallaun/mneme/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/zachallaun/mneme/actions/workflows/ci.yml)\n\n https://gist.github.com/assets/503938/57073c2c-6243-4b17-a91f-b705f4524dc9 \n\nMneme augments `ExUnit.Assertions` with a set of assertions that know how to update themselves.\nThis is sometimes called snapshot, approval, or golden master testing.\n\nWith Mneme, you write something like...\n\n```elixir\nauto_assert my_function()\n```\n\n...and next time you run your tests, Mneme:\n\n1. runs the code,\n2. generates a pattern from the result,\n3. prints a diff,\n4. and asks if you'd like the test updated.\n\nWhen you say yes, your test now looks like this:\n\n```elixir\nauto_assert %MyAwesomeValue{so: :cool} <- my_function()\n```\n\nThis lets you quickly write lots of tests, and like ordinary tests, you'll see when they fail.\nBut, unlike ordinary tests, Mneme asks if you'd like the test updated for the new value.\n\n**Features:**\n\n  * **Auto-updating assertions:** maintain correct tests as behavior changes during development.\n  * **Alternatives to familiar assertions:** `auto_assert`, `auto_assert_raise`, `auto_assert_receive`, `auto_assert_received`.\n  * **Seamless integration with ExUnit:** no need to change your workflow, just run `mix test`.\n  * **Interactive prompts in your terminal** when a new assertion is added or an existing one changes.\n  * **Syntax-aware diffs** highlight the meaningful changes in a value.\n  * **Built-in test watcher:** see changes immediately with `mix mneme.watch`.","title":"Overview","ref":"readme.html"},{"type":"extras","doc":"1.  Add `:mneme` as a dependency in your `mix.exs`.\n\n    ```elixir\n    defp deps do\n      [\n        {:mneme, \">= 0.0.0\", only: :test}\n      ]\n    end\n    ```\n\n2.  Fetch dependencies and run `mix mneme.install` with `MIX_ENV=test`.\n    You're prompted with a diff before any files are saved.\n\n    ```shell\n    $ mix deps.get\n\n    # If MIX_ENV=test is not set, you will see a \"task could not be found\" error\n    $ MIX_ENV=test mix mneme.install\n    ```\n\n3.  Add `use Mneme` wherever you `use ExUnit.Case`.\n\n    ```elixir\n    defmodule MyTest do\n      use ExUnit.Case, async: true\n      use Mneme\n\n      test \"arithmetic\" do\n        auto_assert 2 + 2\n      end\n    end\n    ```\n\n4.  Run `mix test` and type `y ` when prompted.\n    The `auto_assert` call should be updated to:\n\n    ```elixir\n    auto_assert 4 <- 2 + 2\n    ```","title":"Getting started - Overview","ref":"readme.html#getting-started"},{"type":"extras","doc":"If you'd like to see Mneme in action, you can download and run [examples/tour_mneme.exs](https://github.com/zachallaun/mneme/blob/main/examples/tour_mneme.exs), a standalone tour that only requires that you have Elixir installed.\nGive it a try without installing Mneme into your own project.\n\n```shell\n$ curl -o tour_mneme.exs https://raw.githubusercontent.com/zachallaun/mneme/main/examples/tour_mneme.exs\n\n$ elixir tour_mneme.exs\n```","title":"Interactive tour - Overview","ref":"readme.html#interactive-tour"},{"type":"extras","doc":"","title":"Requirements - Overview","ref":"readme.html#requirements"},{"type":"extras","doc":"Mneme requires Elixir version 1.14 or later.","title":"Elixir - Overview","ref":"readme.html#elixir"},{"type":"extras","doc":"**If you do not use a formatter, the first auto-assertion will reformat the entire file,** introducing unrelated formatting changes.\nMneme rewrites your test scripts when updating an assertion using the formatter configuration for your project.\n\nIt's highly recommended to configure your editor to format Elixir files on-save.\n\nSupported formatters:\n\n  * [`Mix.Tasks.Format`](https://hexdocs.pm/mix/Mix.Tasks.Format.html) (Elixir's default formatter)\n  * [`FreedomFormatter`](https://github.com/marcandre/freedom_formatter)","title":"Formatter - Overview","ref":"readme.html#formatter"},{"type":"extras","doc":"Auto-assertions are run with your normal tests when you run `mix test` and a terminal prompt is used whenever one needs to be updated.\nHere's what that might look like:\n\n![Screenshot of Mneme CLI](https://github.com/zachallaun/mneme/blob/main/docs/assets/images/demo_screenshot.png?raw=true)\n\nWhenever that happens, you have a few options:\n\n|Key|Action|Description|\n|-|-|-|\n|`y`|Accept|Accept the proposed change. The assertion will be re-run and should pass.|\n|`n`|Reject|Reject the proposed change and fail the test.|\n|`s`|Skip|Skip this assertion. The test will not fail, but the `mix test` process will exit with `1`.|\n|`k`|Next|If multiple patterns have been generated, cycle to the next one.|\n|`K`|Last|If multiple patterns have been generated, cycle to the last one.|\n|`j`|Previous|If multiple patterns have been generated, cycle to the previous one.|\n|`J`|First|If multiple patterns have been generated, cycle to the first one.|\n\nNote that the CLI is not available when tests are run in a CI environment.","title":"Command line interface - Overview","ref":"readme.html#command-line-interface"},{"type":"extras","doc":"In a CI environment, Mneme will not attempt to prompt and update any assertions, but will instead fail any tests that would update.\nThis behavior is enabled by the `CI` environment variable, which is set by convention by many continuous integration providers.\n\n```bash\nexport CI=true\n```","title":"Continuous Integration - Overview","ref":"readme.html#continuous-integration"},{"type":"extras","doc":"Special thanks to:\n\n  * [_What if writing tests was a joyful experience?_](https://blog.janestreet.com/the-joy-of-expect-tests/), from the Jane Street Tech Blog, for inspiring this library.\n\n  * [_My Kind of REPL_](https://ianthehenry.com/posts/my-kind-of-repl/), an article by Ian Henry that shows how snapshot testing can change your workflow.\n\n  * [Sourceror](https://github.com/doorgan/sourceror), a library that makes complex code modifications simple.\n\n  * [Rewrite](https://github.com/hrzndhrn/rewrite), which makes updating source code a breeze.\n\n  * [Owl](https://github.com/fuelen/owl), which makes it much easier to build a pretty CLI.\n\n  * [Insta](https://insta.rs/), a snapshot testing tool for Rust, whose great documentation provided an excellent reference for snapshot testing.\n\n  * [assert_value](https://github.com/assert-value/assert_value_elixir), an existing Elixir project that provides similar functionality.","title":"Links and acknowledgements - Overview","ref":"readme.html#links-and-acknowledgements"},{"type":"extras","doc":"# Pattern generation\n\nWhen new auto-assertions are written or when returned values are changed, Mneme rewrites your assertion.\nWe call this *pattern generation*.\n\nThis page documents the kinds of patterns Mneme generates and why.\n\n![Screenshot of new pattern](https://github.com/zachallaun/mneme/blob/main/docs/assets/images/demo_screenshot.png?raw=true)","title":"Pattern generation","ref":"generated_patterns.html"},{"type":"extras","doc":"For any given auto-assertion, multiple patterns may be generated, in which case you will have the ability to \"scroll\" through them and select the one that best represents what you care to assert.\n\nFor instance, imagine you are testing a `MessageBoard.create_post/1` function.\nIt may be sufficient to simply assert that a post was created:\n\n```elixir\ntest \"create_post/1 creates a new post with valid attrs\", %{user: user} do\n  attrs = %{content: \"my post\", author: user}\n\n  auto_assert {:ok, %Post{}} <- MessageBoard.create_post(attrs)\nend\n```\n\nOr you may want to match on additional attributes of the post itself:\n\n```elixir\ntest \"create_post/1 creates a new post with valid attrs\", %{user: user} do\n  attrs = %{content: \"my post\", author: user}\n\n  auto_assert {:ok, %Post{content: \"my post\", author: ^user}} <-\n                MessageBoard.create_post(attrs)\nend\n```\n\nEither of these might be what you want, so instead of picking for you, Mneme would generate both, and give you the option between them.","title":"Multiple patterns - Pattern generation","ref":"generated_patterns.html#multiple-patterns"},{"type":"extras","doc":"Multiple patterns are generally ordered from simple to complex and the one that is selected by default depends on the `:default_pattern` option.\n(You can find more information about configuring Mneme [here](`Mneme#module-configuration`).)\n\nThe default value for `:default_pattern` is `:infer`, which essentially means:\n\n  * If the pattern is for a new assertion, the first (simplest) pattern will be selected.\n  * If an existing pattern is being updated, a _similar_ pattern will be selected first.\n\nUsing the `MessageBoard.create_post/1` test above as an example, consider what might happen if the content of the post changes:\n\n```elixir\ntest \"create_post/1 creates a new post with valid attrs\", %{user: user} do\n  # :content attribute has been updated\n  attrs = %{content: \"my NEW post\", author: user}\n\n  # next time this runs, Mneme will ask to update this assertion\n  auto_assert {:ok, %Post{content: \"my post\", author: ^user}} <-\n                MessageBoard.create_post(attrs)\nend\n```\n\nIf the `:default_pattern` was `:first`, the default selected pattern would be `{:ok, %Post{}}`, but this is unlikely to be what you want.\nUsing `:infer`, the default pattern would be the same as above, with only the `:content` of the post changed.\n\nWhile you won't often have to change `:default_pattern`, there is one trick that can be used to very quickly iterate on some code:\n\n```elixir\n@mneme default_pattern: :last, force_update: true, action: :accept\ntest \"dev\" do\n  auto_assert something_being_worked_on(:foo)\n  auto_assert something_being_worked_on(:bar)\nend\n```\n\nThis combination of options means that, whenever that test is run, Mneme will immediately update the pattern without prompting.\nWith your tests bound to a [keyboard shortcut](vscode_setup.html#keyboard-shortcuts), this can be a very quick way to see what your code is returning.","title":"Default selection - Pattern generation","ref":"generated_patterns.html#default-selection"},{"type":"extras","doc":"These data types have no special handling and use their equivalent data literal in patterns:\n\n  * atoms\n  * integers\n  * floats\n  * tuples\n\n> #### 0.0 in Erlang/OTP 27 {: .warning}\n>\n> In Erlang/OTP 27, [`0.0` no longer matches `-0.0`](https://www.erlang.org/docs/26/general_info/upcoming_incompatibilities#0.0-and--0.0-will-no-longer-be-exactly-equal).\n> If you are using this version or later, Mneme generates the pattern `-0.0`.\n> If you are using an earlier version, `+0.0` is always generated.","title":"Basic data types - Pattern generation","ref":"generated_patterns.html#basic-data-types"},{"type":"extras","doc":"List patterns are generated using square brackets.\nHowever, if the list contains only ASCII-printable integers, it will be identified as a charlist and an additional pattern using `sigil_c/2` will be suggested:\n\n```elixir\n# this assertion...\nauto_assert Enum.map([2, 11, 11], &(&1 + 100))\n\n# ... would suggest these two patterns\nauto_assert [102, 111, 111] <- Enum.map([2, 11, 11], &(&1 + 100))\nauto_assert ~c\"foo\" <- Enum.map([2, 11, 11], &(&1 + 100))\n```","title":"Lists and charlists - Pattern generation","ref":"generated_patterns.html#lists-and-charlists"},{"type":"extras","doc":"Patterns for strings and binaries follow these rules:\n\n  * If the string is not printable, a bitstring pattern using `<<>>` is generated.\n  * If the string is printable, a pattern using `\"` is generated.\n  * If the string is printable and contains a newline, a heredoc pattern using `\"\"\"` is generated.","title":"Strings and binaries - Pattern generation","ref":"generated_patterns.html#strings-and-binaries"},{"type":"extras","doc":"For new assertions, map patterns will always include all of the keys present in the map.\nWhen updating an existing assertion, however, a pattern using fewer keys will be generated if the existing pattern excludes some keys.\nFor example:\n\n```elixir\n# if this value...\nauto_assert %{x: 1} <- %{x: 1, y: 2, z: 3}\n\n# ... is updated to...\nauto_assert %{x: 1} <- %{x: 10, y: 20, z: 30}\n\n# ... then the default suggested pattern would only include :x\nauto_assert %{x: 10} <- %{x: 10, y: 20, z: 30}\n```","title":"Maps - Pattern generation","ref":"generated_patterns.html#maps"},{"type":"extras","doc":"Most structs are similar to maps, with the exception that empty struct patterns like `%MyStruct{}` will be generated even if the struct has fields, while empty map patterns like `%{}` are not (unless the map is truly empty).\nThis is done because it is often useful to assert that a struct of some kind was returned without asserting its content.","title":"Structs - Pattern generation","ref":"generated_patterns.html#structs"},{"type":"extras","doc":"Some built-in structs have preferred syntax or sigil representations that can be used as patterns.\nThese include:\n\n  * `Range` - `1..10`\n  * `Regex` - `~r/abc/`\n  * `DateTime` - `~U[2024-01-01 12:00:00Z]`\n  * `NaiveDateTime` - `~N[2024-01-01 12:00:00]`\n  * `Date` - `~D[2024-01-01]`\n  * `Time` - `~T[12:00:00]`","title":"Struct shorthands - Pattern generation","ref":"generated_patterns.html#struct-shorthands"},{"type":"extras","doc":"If the struct was defined using `Ecto.Schema`, additional fields will be excluded from the pattern:\n\n  * Primary keys like `id`\n  * Autogenerated fields like `inserted_at` and `updated_at`\n  * Unloaded associations\n\nThis is done because these fields are unstable and generating a pattern with them would cause the test to update every time it is run.","title":"Ecto structs - Pattern generation","ref":"generated_patterns.html#ecto-structs"},{"type":"extras","doc":"Some non-serializable data types do not have a data-literal representation and require guards in order to match on them.\nMneme will generate patterns using guards for PIDs, references, ports, and functions.\nFor example:\n\n```elixir\n# this assertion...\nauto_assert self()\n\n# ... will generate this pattern\nauto_assert pid when is_pid(pid) <- self()\n```","title":"PIDs, references, ports, and functions - Pattern generation","ref":"generated_patterns.html#pids-references-ports-and-functions"},{"type":"extras","doc":"Mneme will use the pin operator `^/1` if a value or element in a collection is the same as a variable currently in scope.\n\n```elixir\nref = make_ref()\n\n# this assertion...\nauto_assert Map.put(%{}, :ref, ref)\n\n# ... will generate this pattern\nauto_assert `%{ref: ^ref} <- Map.put(%{}, :ref, ref)\n```","title":"Pinned variables - Pattern generation","ref":"generated_patterns.html#pinned-variables"},{"type":"extras","doc":"# VS Code Setup\n\nIf you are using Visual Studio Code, there are a couple of things that you can do to smooth out the workflow of running and updating your tests.","title":"VS Code","ref":"vscode_setup.html"},{"type":"extras","doc":"VS Code supports [custom tasks](https://code.visualstudio.com/Docs/editor/tasks#_custom-tasks), which allow you to, among other things, run command-line tools using editor-contextual information like the project you're working on, the file you're in, or the line you're on.\nCustom tasks are accessible by running the command `Tasks: Run Task`, but can also be bound to keyboard shortcuts (see below).\n\nI personally use three custom tasks for testing:\n\n  * `Run tests` - `mix test`\n  * `Run stale tests` - `mix test --stale`\n  * `Run tests in current file` - `mix test FILE`\n  * `Run test at cursor` - `mix test FILE:LINE`\n\nTo set these up:\n\n  1. Run the command `Tasks: Open User Tasks`. This will open your global `tasks.json` that will apply to all projects. (You can optionally use a local `.vscode/tasks.json` file per-project.)\n  2. Add the three tasks below and save the file.\n\n```json\n{\n  \"version\": \"2.0.0\",\n  \"tasks\": [\n    {\n      \"label\": \"Run tests\",\n      \"type\": \"shell\",\n      \"command\": \"mix\",\n      \"args\": [\"test\"],\n      \"options\": {\n        \"cwd\": \"${workspaceFolder}\"\n      },\n      \"presentation\": {\n        \"focus\": true\n      },\n      \"group\": \"test\"\n    },\n    {\n      \"label\": \"Run stale tests\",\n      \"type\": \"shell\",\n      \"command\": \"mix\",\n      \"args\": [\"test\", \"--stale\"],\n      \"options\": {\n        \"cwd\": \"${workspaceFolder}\"\n      },\n      \"presentation\": {\n        \"focus\": true\n      },\n      \"group\": \"test\"\n    },\n    {\n      \"label\": \"Run tests in current file\",\n      \"type\": \"shell\",\n      \"command\": \"mix\",\n      \"args\": [\"test\", \"${relativeFile}\"],\n      \"options\": {\n        \"cwd\": \"${workspaceFolder}\"\n      },\n      \"presentation\": {\n        \"focus\": true\n      },\n      \"runOptions\": {\n        \"reevaluateOnRerun\": false\n      },\n      \"group\": \"test\"\n    },\n    {\n      \"label\": \"Run test at cursor\",\n      \"type\": \"shell\",\n      \"command\": \"mix\",\n      \"args\": [\"test\", \"${relativeFile}:${lineNumber}\"],\n      \"options\": {\n        \"cwd\": \"${workspaceFolder}\"\n      },\n      \"presentation\": {\n        \"focus\": true\n      },\n      \"runOptions\": {\n        \"reevaluateOnRerun\": false\n      },\n      \"group\": \"test\"\n    }\n  ]\n}\n```\n\nOnce saved, these tasks should immediately be available through `Tasks: Run Task` or `Tasks: Run Test Task`.","title":"Custom tasks for testing - VS Code","ref":"vscode_setup.html#custom-tasks-for-testing"},{"type":"extras","doc":"To assign keyboard shortcuts to the three tasks created above:\n\n  1. Run `Preferences: Open Keyboard Shortcuts (JSON)`.\n  2. Add the shortcuts below and save the file.\n\n```json\n{\n  \"key\": \"ctrl+space a\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Run tests\"\n},\n{\n  \"key\": \"ctrl+space s\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Run stale tests\"\n},\n{\n  \"key\": \"ctrl+space f\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Run tests in current file\"\n},\n{\n  \"key\": \"ctrl+space c\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Run test at cursor\"\n},\n```\n\nThe shortcuts above represent my own personal preferences and can be replaced with whatever you'd prefer.","title":"Keyboard shortcuts - VS Code","ref":"vscode_setup.html#keyboard-shortcuts"},{"type":"extras","doc":"In addition to the tasks and keyboard shortcuts above, you may want to add some tasks that use `mix mneme.watch`.\n\n```json\n{\n  \"label\": \"Watch stale tests\",\n  \"type\": \"shell\",\n  \"command\": \"mix\",\n  \"args\": [\"mneme.watch\", \"--stale\"],\n  \"options\": {\n    \"cwd\": \"${workspaceFolder}\"\n  },\n  \"presentation\": {\n    \"focus\": false\n  },\n  \"group\": \"test\"\n},\n{\n  \"label\": \"Watch tests in current file\",\n  \"type\": \"shell\",\n  \"command\": \"mix\",\n  \"args\": [\"mneme.watch\", \"${relativeFile}\"],\n  \"options\": {\n    \"cwd\": \"${workspaceFolder}\"\n  },\n  \"presentation\": {\n    \"focus\": false\n  },\n  \"runOptions\": {\n    \"reevaluateOnRerun\": false\n  },\n  \"group\": \"test\"\n},\n{\n  \"label\": \"Watch test at cursor\",\n  \"type\": \"shell\",\n  \"command\": \"mix\",\n  \"args\": [\"mneme.watch\", \"${relativeFile}:${lineNumber}\"],\n  \"options\": {\n    \"cwd\": \"${workspaceFolder}\"\n  },\n  \"presentation\": {\n    \"focus\": false\n  },\n  \"runOptions\": {\n    \"reevaluateOnRerun\": false\n  },\n  \"group\": \"test\"\n},\n```\n\nAlong with their keyboard shortcuts:\n\n```json\n{\n  \"key\": \"ctrl+space w s\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Watch stale tests\"\n},\n{\n  \"key\": \"ctrl+space w f\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Watch tests in current file\"\n},\n{\n  \"key\": \"ctrl+space w c\",\n  \"command\": \"workbench.action.tasks.runTask\",\n  \"args\": \"Watch test at cursor\"\n},\n```","title":"Integrating `mix mneme.watch` - VS Code","ref":"vscode_setup.html#integrating-mix-mneme-watch"},{"type":"extras","doc":"To understand how Mneme works, we'll follow the order of execution when running `mix test`.\nAfterwards, we'll dive into some specific areas of interest.","title":"Under the hood","ref":"architecture.html"},{"type":"extras","doc":"1. `Mneme.start/1` is called first. This modifies the ExUnit configuration and starts the Mneme server, a `GenServer` that coordinates user interaction, manages IO, and stores assertion state.\n\n2. Test modules are loaded and Mneme's macros are expanded:\n    * `use Mneme` registers module attributes used for configuration, like `@mneme`.\n\n    * `auto_assert*` macros capture their arguments and environment in `%Mneme.Assertion{}` structs and output function calls that will run with the test and do the real heavy lifting.\n\n3. Tests begin to run. The Mneme server begins capturing all output from ExUnit, only flushing it to the console when the user is not being prompted.\n\n4. Auto-assertions run as tests are executed. Exactly what this means depends on the type of assertion (`auto_assert`, `auto_assert_raise`, etc.) and whether it is a new assertion with no reference value or not. The basic order of operations is:\n    * Capture the value being asserted and compare it against the reference value, if present. If it succeeds, carry on.\n\n    * If the assertion fails or there wasn't a reference value to begin with, a call is made to the Mneme server to update it.\n\n    * A set of patterns are constructed and presented to the user in diffs.\n\n    * The user either selects a pattern or rejects them. If selected, the update is stored for later and the test continues. If rejected, the test fails.\n\n5. Once all tests complete, the Mneme server updates the test files for any patched assertions and prints a summary.","title":"Overview - Under the hood","ref":"architecture.html#overview"},{"type":"extras","doc":"TODO","title":"Generating assertions - Under the hood","ref":"architecture.html#generating-assertions"},{"type":"extras","doc":"TODO","title":"Server responsibilities - Under the hood","ref":"architecture.html#server-responsibilities"},{"type":"extras","doc":"TODO","title":"Terminal UI - Under the hood","ref":"architecture.html#terminal-ui"},{"type":"extras","doc":"TODO","title":"Diffing - Under the hood","ref":"architecture.html#diffing"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}